@@ -311,7 +311,11 @@ class CommonQuerySet(QuerySet):
         return res
 
     def get_criteria(self, json=dict()):
-        data = json.get('data', dict())
+
+        if json is None:
+            data = dict()
+        else:
+            data = json.get('data', dict())
         _data = dict()
         if data is not None:
             for key, value in data.items():
