@@ -47,14 +47,14 @@ class V8Exch:
             if index == -1:
                 self.tag = tag
                 self.param_type = self.attributes.get(tag)
-                if self.param_type == None:
+                if self.param_type is None:
                     self.param_type, created = Param_type.objects.get_or_create(code=tag)
                     setAttr(self.attributes, tag, self.param_type)
             else:
                 tag = tag.replace('CatalogObject.', '')
                 self.tag = tag
                 self.entity = self.entities.get(tag)
-                if self.entity == None:
+                if self.entity is None:
                     self.entity, created = Entity_1c.objects.get_or_create(code=tag)
                     setAttr(self.entities, tag, self.entity)
 
