@@ -14,8 +14,8 @@ class Messages_filesQuerySet(CryptoQuerySet):
 
 class Messages_filesManager(CryptoManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'format': record.format,
