@@ -28,8 +28,8 @@ class Messages_viewQuerySet(MessagesQuerySet):
 
 class Messages_viewManager(MessagesManager):
 
-    @staticmethod
-    def getRecord(record, enabled=None):
+    @classmethod
+    def getRecord(cls, record, enabled=None):
         res = {
             'date_create': record.date_create,
             'deliting': record.deliting,
